<template>
  <el-dialog
    top="10vh"
    width="60%"
    :fullscreen="isFullScreen"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <template slot="title">
      <i
        :class="isFullScreen ? 'icon-zuixiaohua' : 'icon-quanpingzuidahua'"
        style="position: absolute; right: 52px; float: right"
        @click="fullscreen"
      >
      </i>
      <span>创建主生产计划</span>
    </template>

    <el-form :model="dataForm" :rules="dataRule" ref="dataForm" class="l-mes">
      <div class="avue-crud">
        <el-table
          :data="dataForm.mpsRequirements"
          style="width: 100%"
          class="mps-table"
          height="500px"
        >
          <el-table-column
            header-align="center"
            align="center"
            label="需求编号"
            width="120px"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.indeRequNo }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="零件号"
            width="120px"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.partNo }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="零件名称"
            width="200px"
            show-overflow-tooltip
          >
            <template slot-scope="scope">
              <el-form-item class=" inline-el-hidden">{{
                scope.row.partName
              }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="需求数量"
            width="90px"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.qtyRequired }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="已计划数量"
            width="120px"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.planRequired }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            prop="remainderRequired"
            header-align="center"
            align="center"
            label="本次计划数量"
            width="170px"
          >
            <template scope="scope">
              <el-form-item
                :prop="'mpsRequirements.' + scope.$index"
                :rules="rules.qtyPlaned"
              >
                <el-input
                  v-model="scope.row.qtyPlaned"
                  placeholder=""
                ></el-input>
              </el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            label="需求日期"
            width="160px"
          >
            <template slot-scope="scope">
              <el-form-item>{{ scope.row.requiredDate }}</el-form-item>
            </template>
          </el-table-column>
          <el-table-column
            header-align="center"
            align="center"
            show-overflow-tooltip
            label="备注"
          >
            <template slot-scope="scope">
              <el-form-item>
                <el-input v-model="scope.row.remark" placeholder=""></el-input>
              </el-form-item>
            </template>
          </el-table-column>
        </el-table>
      </div>
    </el-form>

    <div slot="footer" class="dialog-footer">
      <el-button type="info" @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </div>
  </el-dialog>
</template>

<script>
import { createMasterProductionSchedule } from '@/api/plan/mpsrequirements'
import { validateQtyPlaned } from '@/util/validate'

export default {
  data() {
    return {
      isFullScreen: false,
      visible: true,
      dataForm: {
        mpsRequirements: []
      },
      dataRule: {},
      isSubmit: false
    }
  },
  methods: {
    init(mpsRequirements) {
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        this.dataForm.mpsRequirements = []
        this.dataForm.mpsRequirements = JSON.parse(
          JSON.stringify(mpsRequirements)
        )
      })
    },
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          createMasterProductionSchedule(this.dataForm.mpsRequirements).then(
            (res) => {
              this.$message.success('主生产计划创建成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList', 1)
              this.$router.push({ path: '../masterproductionschedule/index' })
            }
          )
        } else {
          this.isSubmit = false
        }
      })
    },
    // 全屏
    fullscreen() {
      this.isFullScreen = !this.isFullScreen
    }
  },
  computed: {
    rules: function() {
      return {
        qtyPlaned: [{ validator: validateQtyPlaned, trigger: 'blur' }]
      }
    }
  }
}
</script>
<style scoped>
.mps-table .el-table__row > td {
  border: none;
}

.mps-table::before {
  height: 0px;
}
/*
字符串过长时，隐藏显示省略号
*/
.inline-el-hidden {
  display: block;
  width: 93%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin: 0 auto;
}
</style>
